package com.game.business.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.game.business.domain.AppGameMoney;

/**
 * 游戏投注金额Mapper接口
 *
 * @author game
 * @date 2024-08-29
 */
public interface AppGameMoneyMapper extends BaseMapper<AppGameMoney> {
    /**
     * 查询游戏投注金额
     *
     * @param id 游戏投注金额主键
     * @return 游戏投注金额
     */
    public AppGameMoney selectAppGameMoneyById(Long id);

    /**
     * 查询游戏投注金额列表
     *
     * @param appGameMoney 游戏投注金额
     * @return 游戏投注金额集合
     */
    public List<AppGameMoney> selectAppGameMoneyList(AppGameMoney appGameMoney);

    /**
     * 新增游戏投注金额
     *
     * @param appGameMoney 游戏投注金额
     * @return 结果
     */
    public int insertAppGameMoney(AppGameMoney appGameMoney);

    /**
     * 修改游戏投注金额
     *
     * @param appGameMoney 游戏投注金额
     * @return 结果
     */
    public int updateAppGameMoney(AppGameMoney appGameMoney);

    /**
     * 删除游戏投注金额
     *
     * @param id 游戏投注金额主键
     * @return 结果
     */
    public int deleteAppGameMoneyById(Long id);

    /**
     * 批量删除游戏投注金额
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppGameMoneyByIds(Long[] ids);
}