package com.game.business.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.game.common.core.domain.HttpRetArr;
import com.game.common.core.domain.R;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.game.common.annotation.Log;
import com.game.common.core.controller.BaseController;
import com.game.common.core.domain.AjaxResult;
import com.game.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.game.business.domain.AppGameMoney;
import com.game.business.service.IAppGameMoneyService;
import com.game.common.utils.poi.ExcelUtil;
import com.game.common.core.page.TableDataInfo;

/**
 * 游戏投注金额Controller
 * 
 * @author game
 * @date 2024-08-29
 */
@RestController
@RequestMapping("/business/money")
@Api(value = "AppGameMoneyController", description = "游戏投注金额接口", tags = {"游戏投注金额"})
public class AppGameMoneyController extends BaseController
{
    @Autowired
    private IAppGameMoneyService appGameMoneyService;

    /**
     * 查询游戏投注金额列表
     */
    @PreAuthorize("@ss.hasPermi('business:money:list')")
    @GetMapping("/list")
    @ApiOperation(value = "查询游戏投注金额列表", notes = "获取游戏投注金额列表")
    public TableDataInfo<AppGameMoney> list(AppGameMoney appGameMoney)
    {
        startPage();
        List<AppGameMoney> list = appGameMoneyService.selectAppGameMoneyList(appGameMoney);
        return getDataTable(list);
    }

    /**
     * 导出游戏投注金额列表
     */
    @PreAuthorize("@ss.hasPermi('business:money:export')")
    @Log(title = "游戏投注金额", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出游戏投注金额列表", notes = "导出游戏投注金额列表")
    public void export(HttpServletResponse response, AppGameMoney appGameMoney)
    {
        List<AppGameMoney> list = appGameMoneyService.selectAppGameMoneyList(appGameMoney);
        ExcelUtil<AppGameMoney> util = new ExcelUtil<AppGameMoney>(AppGameMoney.class);
        util.exportExcel(response, list, "游戏投注金额数据");
    }

    /**
     * 获取游戏投注金额详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:money:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取游戏投注金额详细信息", notes = "获取游戏投注金额详细信息")
    public R<AppGameMoney> getInfo(@PathVariable("id") Long id)
    {
        return R.ok(appGameMoneyService.selectAppGameMoneyById(id));
    }

    /**
     * 新增游戏投注金额
     */
    @PreAuthorize("@ss.hasPermi('business:money:add')")
    @Log(title = "游戏投注金额", businessType = BusinessType.INSERT)
    @ApiOperation(value = "新增游戏投注金额", notes = "新增游戏投注金额")
    @PostMapping
    public R add(@RequestBody AppGameMoney appGameMoney)
    {
        return R.ok(appGameMoneyService.insertAppGameMoney(appGameMoney));
    }

    /**
     * 修改游戏投注金额
     */
    @PreAuthorize("@ss.hasPermi('business:money:edit')")
    @Log(title = "游戏投注金额", businessType = BusinessType.UPDATE)
    @ApiOperation(value = "修改游戏投注金额", notes = "修改游戏投注金额")
    @PutMapping
    public R edit(@RequestBody AppGameMoney appGameMoney)
    {
        return R.ok(appGameMoneyService.updateAppGameMoney(appGameMoney));
    }

    /**
     * 删除游戏投注金额
     */
    @PreAuthorize("@ss.hasPermi('business:money:remove')")
    @Log(title = "游戏投注金额", businessType = BusinessType.DELETE)
    @ApiOperation(value = "删除游戏投注金额", notes = "删除游戏投注金额")
	@DeleteMapping("/{ids}")
    public R remove(@PathVariable Long[] ids)
    {
        return R.ok(appGameMoneyService.deleteAppGameMoneyByIds(ids));
    }


    /**
     * 查询游戏投注金额列表
     */
    @GetMapping("/moneyList")
    @ApiOperation(value = "查询游戏投注选项", notes = "查询游戏投注选项")
    public HttpRetArr<AppGameMoney> moneyList(AppGameMoney appGameMoney)
    {
        List<AppGameMoney> list = appGameMoneyService.selectAppGameMoneyList(appGameMoney);
        return HttpRetArr.success("查询成功",list);
    }
}
